@@ -10,7 +10,7 @@ Kernel-Debian_64bit_meltdown-patched
 </name>
 
 <description>  
-Fallback Debian 4.9 64bit linux kernel (Meltdown patched)
+Fallback Debian 4.19 64bit linux kernel (Meltdown patched)
 </description>
 
 <installable>
@@ -20,13 +20,11 @@ Fallback Debian 4.9 64bit linux kernel (Meltdown patched)
 <screenshot>none</screenshot>
 
 <preinstall>
-echo "---- in preprocessing ----"
-echo "---- preprocessing done----"
 </preinstall>
 
 <install_package_names>
-linux-image-4.9.0-15-amd64
-linux-headers-4.9.0-15-amd64
+linux-image-4.19.0-6-amd64
+linux-headers-4.19.0-6-amd64
 </install_package_names>
 
 <postinstall>
@@ -34,8 +32,8 @@ linux-headers-4.9.0-15-amd64
 </postinstall>
 
 <uninstall_package_names>
-linux-image-4.9.0-15-amd64
-linux-headers-4.9.0-15-amd64
+linux-image-4.19.0-6-amd64
+linux-headers-4.19.0-6-amd64
 </uninstall_package_names>
 
 </app>
